@@ -31,6 +31,7 @@ typedef struct
   cairo_surface_t *surface;
   guint            tick_handler;
   gdouble          x_offset;
+  guint            missed_count;
   guint            surface_dirty : 1;
 } DzlGraphViewPrivate;
 
@@ -125,6 +126,21 @@ dzl_graph_view_tick_cb (GtkWidget     *widget,
   if ((priv->surface == NULL) || (priv->model == NULL) || !gtk_widget_get_visible (widget))
     goto remove_handler;
 
+  /*
+   * If we've missed drawings for the last 10 tick callbacks, chances are we're
+   * visible, but not being displayed to the user because we're not top-most.
+   * Disable ourselves in that case too so that we don't spin the frame-clock.
+   *
+   * We'll be re-enabled when the next ensure_surface() is called (upon a real
+   * draw by the system).
+   *
+   * The missed_count is reset on draw().
+   */
+  if (priv->missed_count > 10)
+    goto remove_handler;
+  else
+    priv->missed_count++;
+
   timespan = dzl_graph_view_model_get_timespan (priv->model);
   if (timespan == 0)
     goto remove_handler;
@@ -236,6 +252,8 @@ dzl_graph_view_draw (GtkWidget *widget,
 
   g_assert (DZL_IS_GRAPH_VIEW (self));
 
+  priv->missed_count = 0;
+
   gtk_widget_get_allocation (widget, &alloc);
 
   style_context = gtk_widget_get_style_context (widget);
@@ -270,14 +288,14 @@ dzl_graph_view_size_allocate (GtkWidget     *widget,
   gtk_widget_get_allocation (widget, &old_alloc);
 
   if ((old_alloc.width != alloc->width) || (old_alloc.height != alloc->height))
-    g_clear_pointer (&priv->surface, cairo_surface_destroy);
+    dzl_clear_pointer (&priv->surface, cairo_surface_destroy);
 
   GTK_WIDGET_CLASS (dzl_graph_view_parent_class)->size_allocate (widget, alloc);
 }
 
 static void
-dzl_graph_view__model_changed (DzlGraphView  *self,
-                               DzlGraphModel *model)
+dzl_graph_view__model__changed (DzlGraphView  *self,
+                                DzlGraphModel *model)
 {
   DzlGraphViewPrivate *priv = dzl_graph_view_get_instance_private (self);
 
@@ -289,6 +307,20 @@ dzl_graph_view__model_changed (DzlGraphView  *self,
   dzl_graph_view_clear_surface (self);
 }
 
+static void
+dzl_graph_view__model__notify_timespan (DzlGraphView  *self,
+                                        GParamSpec    *pspec,
+                                        DzlGraphModel *model)
+{
+  g_assert (DZL_IS_GRAPH_VIEW (self));
+  g_assert (DZL_IS_GRAPH_MODEL (model));
+
+  /* Avoid this in a number of scenarios */
+  if (gtk_widget_get_visible (GTK_WIDGET (self)) &&
+      gtk_widget_get_child_visible (GTK_WIDGET (self)))
+    gtk_widget_queue_draw (GTK_WIDGET (self));
+}
+
 static void
 dzl_graph_view_destroy (GtkWidget *widget)
 {
@@ -301,6 +333,8 @@ dzl_graph_view_destroy (GtkWidget *widget)
       priv->tick_handler = 0;
     }
 
+  dzl_clear_pointer (&priv->surface, cairo_surface_destroy);
+
   GTK_WIDGET_CLASS (dzl_graph_view_parent_class)->destroy (widget);
 }
 
@@ -312,8 +346,7 @@ dzl_graph_view_finalize (GObject *object)
 
   g_clear_object (&priv->model);
   g_clear_object (&priv->model_signals);
-  g_clear_pointer (&priv->surface, cairo_surface_destroy);
-  g_clear_pointer (&priv->renderers, g_ptr_array_unref);
+  dzl_clear_pointer (&priv->renderers, g_ptr_array_unref);
 
   G_OBJECT_CLASS (dzl_graph_view_parent_class)->finalize (object);
 }
@@ -375,7 +408,7 @@ dzl_graph_view_class_init (DzlGraphViewClass *klass)
                          "Table",
                          "The data model for the graph.",
                          DZL_TYPE_GRAPH_MODEL,
-                         (G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
+                         (G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY | G_PARAM_STATIC_STRINGS));
 
   g_object_class_install_properties (object_class, LAST_PROP, properties);
 
@@ -405,13 +438,13 @@ dzl_graph_view_init (DzlGraphView *self)
 
   dzl_signal_group_connect_object (priv->model_signals,
                                    "notify::timespan",
-                                   G_CALLBACK (gtk_widget_queue_allocate),
+                                   G_CALLBACK (dzl_graph_view__model__notify_timespan),
                                    self,
                                    G_CONNECT_SWAPPED);
 
   dzl_signal_group_connect_object (priv->model_signals,
                                    "changed",
-                                   G_CALLBACK (dzl_graph_view__model_changed),
+                                   G_CALLBACK (dzl_graph_view__model__changed),
                                    self,
                                    G_CONNECT_SWAPPED);
 }
