@@ -57,10 +57,7 @@ dzl_shortcut_closure_chain_append (DzlShortcutClosureChain *chain,
   if (chain == NULL)
     return element;
 
-  if (element == NULL)
-    return chain;
-
-  ret = g_slist_concat (&chain->node, &element->node)->data;
+  ret = g_slist_append (&chain->node, &element->node)->data;
 
   g_return_val_if_fail (ret != NULL, NULL);
 
@@ -83,14 +80,14 @@ dzl_shortcut_closure_chain_free (DzlShortcutClosureChain *chain)
     dzl_shortcut_closure_chain_free (chain->node.next->data);
 
   if (chain->type == DZL_SHORTCUT_CLOSURE_ACTION)
-    g_clear_pointer (&chain->action.params, g_variant_unref);
+    dzl_clear_pointer (&chain->action.params, g_variant_unref);
   else if (chain->type == DZL_SHORTCUT_CLOSURE_CALLBACK)
     {
       if (chain->callback.notify)
-        g_clear_pointer (&chain->callback.user_data, chain->callback.notify);
+        dzl_clear_pointer (&chain->callback.user_data, chain->callback.notify);
     }
   else if (chain->type == DZL_SHORTCUT_CLOSURE_SIGNAL)
-    g_clear_pointer (&chain->signal.params, g_array_unref);
+    dzl_clear_pointer (&chain->signal.params, g_array_unref);
 
   g_slice_free (DzlShortcutClosureChain, chain);
 }
@@ -361,9 +358,6 @@ signal_activate (DzlShortcutClosureChain *chain,
     g_value_unset (&params[i]);
   g_free (params);
 
-  if (query.return_type != G_TYPE_NONE)
-    g_value_unset (&return_value);
-
   return GDK_EVENT_STOP;
 
 parameter_mismatch:
