@@ -31,6 +31,11 @@
  *
  * This might be useful when you want to change a label based on some
  * selection state without it affecting the size request or layout.
+ *
+ * Remember that bold and non-bold variants of fonts can often be very
+ * different in terms of styling. To reduce the chances that you see
+ * shifts in placement, you may want to set the #GtkLabel:xalign or
+ * #GtkLabel:halign properties to 0.0 or %GTK_ALIGN_START respectively.
  */
 
 struct _DzlBoldingLabel
@@ -158,7 +163,6 @@ void
 dzl_bolding_label_set_weight (DzlBoldingLabel *self,
                               PangoWeight      weight)
 {
-  PangoAttrList *filtered;
   PangoAttrList *attrs;
   PangoAttrList *copy;
   PangoAttribute *attr;
@@ -171,11 +175,10 @@ dzl_bolding_label_set_weight (DzlBoldingLabel *self,
   else
     copy = pango_attr_list_new ();
   attr = pango_attr_weight_new (weight);
-  filtered = pango_attr_list_filter (copy, remove_weights, attr);
+  pango_attr_list_filter (copy, remove_weights, attr);
   pango_attr_list_insert (copy, attr);
   gtk_label_set_attributes (GTK_LABEL (self), copy);
   gtk_widget_queue_draw (GTK_WIDGET (self));
-  pango_attr_list_unref (filtered);
   pango_attr_list_unref (copy);
 }
 
